/* wbxmltest.c --- test driver for wbxml.c */

/*
 * Copyright (C) 2000 Roger Willcocks
 * rogerw@centipede.co.uk
 *
 * 20 feb 00	rkww	split out from wbxml.c
 */

#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>
#include <setjmp.h>

#include <fcntl.h>
#ifdef _WIN32
#include <io.h>
#endif
#ifndef O_BINARY
#define O_BINARY 0
#endif

#include "wbxml.h"
extern int allocs;

/*
 * debug helper (same format as Nokia wap toolkit)
 */
static void hexoutput(char* buffer, int length)
{
    int i;
    for (i = 0; i < ((length + 15) & ~15); i++) {
	if ((i & 15) == 0)
	    printf("%08x ", i);
	printf((i < length && (i & 15) == 8) ? "-" : " ");
	if (i < length)
	    printf("%02x", buffer[i] & 0xff);
	else
	    printf("  ");
	if ((i & 15) == 15) {
	    int j;
	    printf("  ");
	    for (j = i - 15; j <= i; j++) {
		if (j < length) {
		    int c = (buffer[j] & 0xff);
		    if (c >= ' ' && c <= '~')
			;
		    else
			c = '.';
		    printf("%c", c);
		}
	    }
	    printf("\n");
	}
    }
}


int main(int argc, char *argv[])
{
    char inputbuffer[10000];
    char outputbuffer[2000];
    int f, bytes, i;

    wmlparser* parser;

    inputbuffer[0] = 0;

    /* wmlparser <file.wml> */

    f = open(argv[1], O_RDONLY|O_BINARY);
    read(f, inputbuffer, sizeof(inputbuffer));
    close(f);

    parser = NewWmlParser();

    bytes = ParseWml(parser, inputbuffer, outputbuffer);

    if (bytes > 0) {
	hexoutput(outputbuffer, bytes);
	i = open("c:/temp/out.wmlc", O_CREAT|O_RDWR|O_TRUNC|O_BINARY, 0666);
	write(i, outputbuffer, bytes);
	close(i);

	printf("*** binary output is in c:/temp/out.wmlc ***\n");
    }
    else
	printf("%s\n", outputbuffer); /* error string */

    DeleteWmlParser(parser);

    printf("allocs = %d\n", allocs);
    return bytes;
}

/* end */

